//
//  PickerViewController.swift
//  VoltageInput
//
//  Created by Phidgets on 2018-01-25.
//  Copyright © 2018 Phidgets. All rights reserved.
//

import UIKit
import Phidget22Swift

class PickerViewController: UIViewController, UIPickerViewDelegate, UIPickerViewDataSource {
    
    @IBOutlet var pickerTitle: UILabel!
    @IBOutlet var pickerBox: UIView!
    @IBOutlet var pickerView: UIPickerView!
    var pickerArray = [String]()
    var titleName = String()
    var ch = VoltageInput()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        pickerBox.layer.cornerRadius = 5
        pickerBox.layer.masksToBounds = true
        pickerTitle.text = titleName
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func numberOfComponents(in pickerView: UIPickerView) -> Int {
        return 1
    }
    
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        return pickerArray.count
    }
    
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        return pickerArray[row]
    }
    
    func pickerView(_ pickerView: UIPickerView, viewForRow row: Int, forComponent component: Int, reusing view: UIView?) -> UIView {
        var text = (view as? UILabel)
        if text == nil{
            text = UILabel.init()
        }
        text?.font = UIFont.systemFont(ofSize: 25, weight: UIFont.Weight.light)
        text?.textAlignment = .center
        text?.adjustsFontSizeToFitWidth = true
        text?.text = self.pickerView(pickerView, titleForRow: row, forComponent: component)
        
        return text!
    }
    
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        let resultString:String = (pickerArray[row])
        do{
            //handle cases that can't be differentiated by number
            if resultString == "Generic Voltage Sensor"{
                try ch.setSensorType(VoltageSensorType.voltage)
                return
            }
            else if resultString == "1130 - pH Adapter"{
                try ch.setSensorType(VoltageSensorType.PN_1130_pH)
                return
            }
            else if resultString == "1130 - ORP Adapter"{
                try ch.setSensorType(VoltageSensorType.PN_1130_ORP)
                return
            }
            else if resultString == "10 mV" {
                try ch.setVoltageRange(VoltageRange.milliVolts_10)
                return
            }
            else if resultString == "40 mV" {
                try ch.setVoltageRange(VoltageRange.milliVolts_40)
                return
            }
            else if resultString == "200 mV" {
                try ch.setVoltageRange(VoltageRange.milliVolts_200)
                return
            }
            else if resultString == "400 mV" {
                try ch.setVoltageRange(VoltageRange.milliVolts_400)
                return
            }
            else if resultString == "312.5 mV" {
                try ch.setVoltageRange(VoltageRange.milliVolts_312_5)
                return
            }
            else if resultString == "400 mV" {
                try ch.setVoltageRange(VoltageRange.milliVolts_400)
                return
            }
            else if resultString == "1000 mV" {
                try ch.setVoltageRange(VoltageRange.milliVolts_1000)
                return
            }
            else if resultString == "2 V" {
                try ch.setVoltageRange(VoltageRange.volts_2)
                return
            }
            else if resultString == "5 V" {
                try ch.setVoltageRange(VoltageRange.volts_5)
                return
            }
            else if resultString == "15 V" {
                try ch.setVoltageRange(VoltageRange.volts_15)
                return
            }
            else if resultString == "40 V" {
                try ch.setVoltageRange(VoltageRange.volts_40)
                return
            }
            else if resultString == "Automatic" {
                try ch.setVoltageRange(VoltageRange.auto)
                return
            }
            //use number to differentiate the rest
            let stringArray = resultString.components(
                separatedBy: CharacterSet.decimalDigits.inverted)
            let s1:String = stringArray[0]
            let sensorType = VoltageSensorType(rawValue:UInt32(10) * UInt32(s1)!)
            try ch.setSensorType(sensorType!)
        } catch let err as PhidgetError {
            outputErrorMessage(errorTitle: "Error Code: \(err.errorCode)", errorMessage: err.description)
        } catch {
            print (error)
        }
        
    }
    
    @IBAction func done(_ sender: AnyObject) {
        self.performSegue(withIdentifier: "digitalOutputDoneSegue", sender: self)
    }
    
    var timeStamp:TimeInterval = 0
    var lastTimeStamp:TimeInterval = 0
    func outputErrorMessage(errorTitle:String, errorMessage:String){
        timeStamp = NSDate.timeIntervalSinceReferenceDate
        //Add a delay for error events so the user does not get bombarded by error events
        if(timeStamp - lastTimeStamp > 5){
            let alert = UIAlertController(title: errorTitle, message: errorMessage, preferredStyle: .alert)
            alert.addAction(UIAlertAction(title: "OK", style: .default, handler: {action -> Void in
            }))
            self.present(alert, animated: true, completion: nil)
            lastTimeStamp = timeStamp
        }
    }
    
}


